pub fn set_override(enabled: bool)Expand description
Set an override value for whether or not colors are supported.
If true is passed,
if_supports_color will always act
as if colors are supported.
If false is passed,
if_supports_color will always act
as if colors are not supported.
This behavior can be disabled using unset_override, allowing
owo-colors to return to inferring if colors are supported.