pub trait DynColor: Sealed {
// Required methods
fn fmt_ansi_fg(&self, f: &mut Formatter<'_>) -> Result;
fn fmt_ansi_bg(&self, f: &mut Formatter<'_>) -> Result;
fn fmt_raw_ansi_fg(&self, f: &mut Formatter<'_>) -> Result;
fn fmt_raw_ansi_bg(&self, f: &mut Formatter<'_>) -> Result;
}Expand description
A trait describing a runtime-configurable color which can displayed using FgDynColorDisplay
or BgDynColorDisplay. If your color will be known at compile time it
is recommended you avoid this.
Required Methods
Sourcefn fmt_ansi_fg(&self, f: &mut Formatter<'_>) -> Result
fn fmt_ansi_fg(&self, f: &mut Formatter<'_>) -> Result
A function to output a ANSI code to a formatter to set the foreground to this color
Sourcefn fmt_ansi_bg(&self, f: &mut Formatter<'_>) -> Result
fn fmt_ansi_bg(&self, f: &mut Formatter<'_>) -> Result
A function to output a ANSI code to a formatter to set the background to this color
Sourcefn fmt_raw_ansi_fg(&self, f: &mut Formatter<'_>) -> Result
fn fmt_raw_ansi_fg(&self, f: &mut Formatter<'_>) -> Result
A function to output a raw ANSI code to a formatter to set the foreground to this color, but without including the ANSI delimiters.
Sourcefn fmt_raw_ansi_bg(&self, f: &mut Formatter<'_>) -> Result
fn fmt_raw_ansi_bg(&self, f: &mut Formatter<'_>) -> Result
A function to output a raw ANSI code to a formatter to set the background to this color, but without including the ANSI delimiters.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".