pub trait OwoColorize: Sized {
Show 57 methods
// Provided methods
fn fg<C: Color>(&self) -> FgColorDisplay<'_, C, Self> { ... }
fn bg<C: Color>(&self) -> BgColorDisplay<'_, C, Self> { ... }
fn black(&self) -> FgColorDisplay<'_, Black, Self> { ... }
fn on_black(&self) -> BgColorDisplay<'_, Black, Self> { ... }
fn red(&self) -> FgColorDisplay<'_, Red, Self> { ... }
fn on_red(&self) -> BgColorDisplay<'_, Red, Self> { ... }
fn green(&self) -> FgColorDisplay<'_, Green, Self> { ... }
fn on_green(&self) -> BgColorDisplay<'_, Green, Self> { ... }
fn yellow(&self) -> FgColorDisplay<'_, Yellow, Self> { ... }
fn on_yellow(&self) -> BgColorDisplay<'_, Yellow, Self> { ... }
fn blue(&self) -> FgColorDisplay<'_, Blue, Self> { ... }
fn on_blue(&self) -> BgColorDisplay<'_, Blue, Self> { ... }
fn magenta(&self) -> FgColorDisplay<'_, Magenta, Self> { ... }
fn on_magenta(&self) -> BgColorDisplay<'_, Magenta, Self> { ... }
fn purple(&self) -> FgColorDisplay<'_, Magenta, Self> { ... }
fn on_purple(&self) -> BgColorDisplay<'_, Magenta, Self> { ... }
fn cyan(&self) -> FgColorDisplay<'_, Cyan, Self> { ... }
fn on_cyan(&self) -> BgColorDisplay<'_, Cyan, Self> { ... }
fn white(&self) -> FgColorDisplay<'_, White, Self> { ... }
fn on_white(&self) -> BgColorDisplay<'_, White, Self> { ... }
fn default_color(&self) -> FgColorDisplay<'_, Default, Self> { ... }
fn on_default_color(&self) -> BgColorDisplay<'_, Default, Self> { ... }
fn bright_black(&self) -> FgColorDisplay<'_, BrightBlack, Self> { ... }
fn on_bright_black(&self) -> BgColorDisplay<'_, BrightBlack, Self> { ... }
fn bright_red(&self) -> FgColorDisplay<'_, BrightRed, Self> { ... }
fn on_bright_red(&self) -> BgColorDisplay<'_, BrightRed, Self> { ... }
fn bright_green(&self) -> FgColorDisplay<'_, BrightGreen, Self> { ... }
fn on_bright_green(&self) -> BgColorDisplay<'_, BrightGreen, Self> { ... }
fn bright_yellow(&self) -> FgColorDisplay<'_, BrightYellow, Self> { ... }
fn on_bright_yellow(&self) -> BgColorDisplay<'_, BrightYellow, Self> { ... }
fn bright_blue(&self) -> FgColorDisplay<'_, BrightBlue, Self> { ... }
fn on_bright_blue(&self) -> BgColorDisplay<'_, BrightBlue, Self> { ... }
fn bright_magenta(&self) -> FgColorDisplay<'_, BrightMagenta, Self> { ... }
fn on_bright_magenta(&self) -> BgColorDisplay<'_, BrightMagenta, Self> { ... }
fn bright_purple(&self) -> FgColorDisplay<'_, BrightMagenta, Self> { ... }
fn on_bright_purple(&self) -> BgColorDisplay<'_, BrightMagenta, Self> { ... }
fn bright_cyan(&self) -> FgColorDisplay<'_, BrightCyan, Self> { ... }
fn on_bright_cyan(&self) -> BgColorDisplay<'_, BrightCyan, Self> { ... }
fn bright_white(&self) -> FgColorDisplay<'_, BrightWhite, Self> { ... }
fn on_bright_white(&self) -> BgColorDisplay<'_, BrightWhite, Self> { ... }
fn bold(&self) -> BoldDisplay<'_, Self> { ... }
fn dimmed(&self) -> DimDisplay<'_, Self> { ... }
fn italic(&self) -> ItalicDisplay<'_, Self> { ... }
fn underline(&self) -> UnderlineDisplay<'_, Self> { ... }
fn blink(&self) -> BlinkDisplay<'_, Self> { ... }
fn blink_fast(&self) -> BlinkFastDisplay<'_, Self> { ... }
fn reversed(&self) -> ReversedDisplay<'_, Self> { ... }
fn hidden(&self) -> HiddenDisplay<'_, Self> { ... }
fn strikethrough(&self) -> StrikeThroughDisplay<'_, Self> { ... }
fn color<Color: DynColor>(
&self,
color: Color,
) -> FgDynColorDisplay<'_, Color, Self> { ... }
fn on_color<Color: DynColor>(
&self,
color: Color,
) -> BgDynColorDisplay<'_, Color, Self> { ... }
fn fg_rgb<const R: u8, const G: u8, const B: u8>(
&self,
) -> FgColorDisplay<'_, CustomColor<R, G, B>, Self> { ... }
fn bg_rgb<const R: u8, const G: u8, const B: u8>(
&self,
) -> BgColorDisplay<'_, CustomColor<R, G, B>, Self> { ... }
fn truecolor(&self, r: u8, g: u8, b: u8) -> FgDynColorDisplay<'_, Rgb, Self> { ... }
fn on_truecolor(
&self,
r: u8,
g: u8,
b: u8,
) -> BgDynColorDisplay<'_, Rgb, Self> { ... }
fn style(&self, style: Style) -> Styled<&Self> { ... }
fn if_supports_color<'a, Out, ApplyFn>(
&'a self,
stream: impl Into<Stream>,
apply: ApplyFn,
) -> SupportsColorsDisplay<'a, Self, Out, ApplyFn>
where ApplyFn: Fn(&'a Self) -> Out { ... }
}Expand description
Extension trait for colorizing a type which implements any std formatter
(Display, Debug, UpperHex,
etc.)
Example
use owo_colors::OwoColorize;
println!("My number is {:#x}!", 10.green());
println!("My number is not {}!", 4.on_red());How to decide which method to use
Do you have a specific color you want to use?
Use the specific color’s method, such as blue or
on_green.
Do you want your colors configurable via generics?
Use fg and bg to make it compile-time configurable.
Do you need to pick a color at runtime?
Use the color, on_color,
truecolor or on_truecolor.
Do you need some other text modifier?
Do you want it to only display colors if it’s a terminal?
- Enable the
supports-colorsfeature - Colorize inside
if_supports_color
Do you need to store a set of colors/effects to apply to multiple things?
Provided Methods
Sourcefn fg<C: Color>(&self) -> FgColorDisplay<'_, C, Self>
fn fg<C: Color>(&self) -> FgColorDisplay<'_, C, Self>
Set the foreground color generically
use owo_colors::{OwoColorize, colors::*};
println!("{}", "red foreground".fg::<Red>());Sourcefn bg<C: Color>(&self) -> BgColorDisplay<'_, C, Self>
fn bg<C: Color>(&self) -> BgColorDisplay<'_, C, Self>
Set the background color generically.
use owo_colors::{OwoColorize, colors::*};
println!("{}", "black background".bg::<Black>());Sourcefn black(&self) -> FgColorDisplay<'_, Black, Self>
fn black(&self) -> FgColorDisplay<'_, Black, Self>
Change the foreground color to black
Sourcefn on_black(&self) -> BgColorDisplay<'_, Black, Self>
fn on_black(&self) -> BgColorDisplay<'_, Black, Self>
Change the background color to black
Sourcefn red(&self) -> FgColorDisplay<'_, Red, Self>
fn red(&self) -> FgColorDisplay<'_, Red, Self>
Change the foreground color to red
Sourcefn on_red(&self) -> BgColorDisplay<'_, Red, Self>
fn on_red(&self) -> BgColorDisplay<'_, Red, Self>
Change the background color to red
Sourcefn green(&self) -> FgColorDisplay<'_, Green, Self>
fn green(&self) -> FgColorDisplay<'_, Green, Self>
Change the foreground color to green
Sourcefn on_green(&self) -> BgColorDisplay<'_, Green, Self>
fn on_green(&self) -> BgColorDisplay<'_, Green, Self>
Change the background color to green
Sourcefn yellow(&self) -> FgColorDisplay<'_, Yellow, Self>
fn yellow(&self) -> FgColorDisplay<'_, Yellow, Self>
Change the foreground color to yellow
Sourcefn on_yellow(&self) -> BgColorDisplay<'_, Yellow, Self>
fn on_yellow(&self) -> BgColorDisplay<'_, Yellow, Self>
Change the background color to yellow
Sourcefn blue(&self) -> FgColorDisplay<'_, Blue, Self>
fn blue(&self) -> FgColorDisplay<'_, Blue, Self>
Change the foreground color to blue
Sourcefn on_blue(&self) -> BgColorDisplay<'_, Blue, Self>
fn on_blue(&self) -> BgColorDisplay<'_, Blue, Self>
Change the background color to blue
Sourcefn magenta(&self) -> FgColorDisplay<'_, Magenta, Self>
fn magenta(&self) -> FgColorDisplay<'_, Magenta, Self>
Change the foreground color to magenta
Sourcefn on_magenta(&self) -> BgColorDisplay<'_, Magenta, Self>
fn on_magenta(&self) -> BgColorDisplay<'_, Magenta, Self>
Change the background color to magenta
Sourcefn purple(&self) -> FgColorDisplay<'_, Magenta, Self>
fn purple(&self) -> FgColorDisplay<'_, Magenta, Self>
Change the foreground color to purple
Sourcefn on_purple(&self) -> BgColorDisplay<'_, Magenta, Self>
fn on_purple(&self) -> BgColorDisplay<'_, Magenta, Self>
Change the background color to purple
Sourcefn cyan(&self) -> FgColorDisplay<'_, Cyan, Self>
fn cyan(&self) -> FgColorDisplay<'_, Cyan, Self>
Change the foreground color to cyan
Sourcefn on_cyan(&self) -> BgColorDisplay<'_, Cyan, Self>
fn on_cyan(&self) -> BgColorDisplay<'_, Cyan, Self>
Change the background color to cyan
Sourcefn white(&self) -> FgColorDisplay<'_, White, Self>
fn white(&self) -> FgColorDisplay<'_, White, Self>
Change the foreground color to white
Sourcefn on_white(&self) -> BgColorDisplay<'_, White, Self>
fn on_white(&self) -> BgColorDisplay<'_, White, Self>
Change the background color to white
Sourcefn default_color(&self) -> FgColorDisplay<'_, Default, Self>
fn default_color(&self) -> FgColorDisplay<'_, Default, Self>
Change the foreground color to the terminal default
Sourcefn on_default_color(&self) -> BgColorDisplay<'_, Default, Self>
fn on_default_color(&self) -> BgColorDisplay<'_, Default, Self>
Change the background color to the terminal default
Sourcefn bright_black(&self) -> FgColorDisplay<'_, BrightBlack, Self>
fn bright_black(&self) -> FgColorDisplay<'_, BrightBlack, Self>
Change the foreground color to bright black
Sourcefn on_bright_black(&self) -> BgColorDisplay<'_, BrightBlack, Self>
fn on_bright_black(&self) -> BgColorDisplay<'_, BrightBlack, Self>
Change the background color to bright black
Sourcefn bright_red(&self) -> FgColorDisplay<'_, BrightRed, Self>
fn bright_red(&self) -> FgColorDisplay<'_, BrightRed, Self>
Change the foreground color to bright red
Sourcefn on_bright_red(&self) -> BgColorDisplay<'_, BrightRed, Self>
fn on_bright_red(&self) -> BgColorDisplay<'_, BrightRed, Self>
Change the background color to bright red
Sourcefn bright_green(&self) -> FgColorDisplay<'_, BrightGreen, Self>
fn bright_green(&self) -> FgColorDisplay<'_, BrightGreen, Self>
Change the foreground color to bright green
Sourcefn on_bright_green(&self) -> BgColorDisplay<'_, BrightGreen, Self>
fn on_bright_green(&self) -> BgColorDisplay<'_, BrightGreen, Self>
Change the background color to bright green
Sourcefn bright_yellow(&self) -> FgColorDisplay<'_, BrightYellow, Self>
fn bright_yellow(&self) -> FgColorDisplay<'_, BrightYellow, Self>
Change the foreground color to bright yellow
Sourcefn on_bright_yellow(&self) -> BgColorDisplay<'_, BrightYellow, Self>
fn on_bright_yellow(&self) -> BgColorDisplay<'_, BrightYellow, Self>
Change the background color to bright yellow
Sourcefn bright_blue(&self) -> FgColorDisplay<'_, BrightBlue, Self>
fn bright_blue(&self) -> FgColorDisplay<'_, BrightBlue, Self>
Change the foreground color to bright blue
Sourcefn on_bright_blue(&self) -> BgColorDisplay<'_, BrightBlue, Self>
fn on_bright_blue(&self) -> BgColorDisplay<'_, BrightBlue, Self>
Change the background color to bright blue
Sourcefn bright_magenta(&self) -> FgColorDisplay<'_, BrightMagenta, Self>
fn bright_magenta(&self) -> FgColorDisplay<'_, BrightMagenta, Self>
Change the foreground color to bright magenta
Sourcefn on_bright_magenta(&self) -> BgColorDisplay<'_, BrightMagenta, Self>
fn on_bright_magenta(&self) -> BgColorDisplay<'_, BrightMagenta, Self>
Change the background color to bright magenta
Sourcefn bright_purple(&self) -> FgColorDisplay<'_, BrightMagenta, Self>
fn bright_purple(&self) -> FgColorDisplay<'_, BrightMagenta, Self>
Change the foreground color to bright purple
Sourcefn on_bright_purple(&self) -> BgColorDisplay<'_, BrightMagenta, Self>
fn on_bright_purple(&self) -> BgColorDisplay<'_, BrightMagenta, Self>
Change the background color to bright purple
Sourcefn bright_cyan(&self) -> FgColorDisplay<'_, BrightCyan, Self>
fn bright_cyan(&self) -> FgColorDisplay<'_, BrightCyan, Self>
Change the foreground color to bright cyan
Sourcefn on_bright_cyan(&self) -> BgColorDisplay<'_, BrightCyan, Self>
fn on_bright_cyan(&self) -> BgColorDisplay<'_, BrightCyan, Self>
Change the background color to bright cyan
Sourcefn bright_white(&self) -> FgColorDisplay<'_, BrightWhite, Self>
fn bright_white(&self) -> FgColorDisplay<'_, BrightWhite, Self>
Change the foreground color to bright white
Sourcefn on_bright_white(&self) -> BgColorDisplay<'_, BrightWhite, Self>
fn on_bright_white(&self) -> BgColorDisplay<'_, BrightWhite, Self>
Change the background color to bright white
Sourcefn bold(&self) -> BoldDisplay<'_, Self>
fn bold(&self) -> BoldDisplay<'_, Self>
Make the text bold
Sourcefn dimmed(&self) -> DimDisplay<'_, Self>
fn dimmed(&self) -> DimDisplay<'_, Self>
Make the text dim
Sourcefn italic(&self) -> ItalicDisplay<'_, Self>
fn italic(&self) -> ItalicDisplay<'_, Self>
Make the text italicized
Sourcefn underline(&self) -> UnderlineDisplay<'_, Self>
fn underline(&self) -> UnderlineDisplay<'_, Self>
Make the text underlined
Sourcefn blink(&self) -> BlinkDisplay<'_, Self>
fn blink(&self) -> BlinkDisplay<'_, Self>
Make the text blink
Sourcefn blink_fast(&self) -> BlinkFastDisplay<'_, Self>
fn blink_fast(&self) -> BlinkFastDisplay<'_, Self>
Make the text blink (but fast!)
Sourcefn reversed(&self) -> ReversedDisplay<'_, Self>
fn reversed(&self) -> ReversedDisplay<'_, Self>
Swap the foreground and background colors
Hide the text
Sourcefn strikethrough(&self) -> StrikeThroughDisplay<'_, Self>
fn strikethrough(&self) -> StrikeThroughDisplay<'_, Self>
Cross out the text
Sourcefn color<Color: DynColor>(
&self,
color: Color,
) -> FgDynColorDisplay<'_, Color, Self>
fn color<Color: DynColor>( &self, color: Color, ) -> FgDynColorDisplay<'_, Color, Self>
Set the foreground color at runtime. Only use if you do not know which color will be used at
compile-time. If the color is constant, use either OwoColorize::fg or
a color-specific method, such as OwoColorize::green,
use owo_colors::{OwoColorize, AnsiColors};
println!("{}", "green".color(AnsiColors::Green));Sourcefn on_color<Color: DynColor>(
&self,
color: Color,
) -> BgDynColorDisplay<'_, Color, Self>
fn on_color<Color: DynColor>( &self, color: Color, ) -> BgDynColorDisplay<'_, Color, Self>
Set the background color at runtime. Only use if you do not know what color to use at
compile-time. If the color is constant, use either OwoColorize::bg or
a color-specific method, such as OwoColorize::on_yellow,
use owo_colors::{OwoColorize, AnsiColors};
println!("{}", "yellow background".on_color(AnsiColors::BrightYellow));Sourcefn fg_rgb<const R: u8, const G: u8, const B: u8>(
&self,
) -> FgColorDisplay<'_, CustomColor<R, G, B>, Self>
fn fg_rgb<const R: u8, const G: u8, const B: u8>( &self, ) -> FgColorDisplay<'_, CustomColor<R, G, B>, Self>
Set the foreground color to a specific RGB value.
Sourcefn bg_rgb<const R: u8, const G: u8, const B: u8>(
&self,
) -> BgColorDisplay<'_, CustomColor<R, G, B>, Self>
fn bg_rgb<const R: u8, const G: u8, const B: u8>( &self, ) -> BgColorDisplay<'_, CustomColor<R, G, B>, Self>
Set the background color to a specific RGB value.
Sourcefn truecolor(&self, r: u8, g: u8, b: u8) -> FgDynColorDisplay<'_, Rgb, Self>
fn truecolor(&self, r: u8, g: u8, b: u8) -> FgDynColorDisplay<'_, Rgb, Self>
Sets the foreground color to an RGB value.
Sourcefn on_truecolor(&self, r: u8, g: u8, b: u8) -> BgDynColorDisplay<'_, Rgb, Self>
fn on_truecolor(&self, r: u8, g: u8, b: u8) -> BgDynColorDisplay<'_, Rgb, Self>
Sets the background color to an RGB value.
Sourcefn if_supports_color<'a, Out, ApplyFn>(
&'a self,
stream: impl Into<Stream>,
apply: ApplyFn,
) -> SupportsColorsDisplay<'a, Self, Out, ApplyFn>where
ApplyFn: Fn(&'a Self) -> Out,
fn if_supports_color<'a, Out, ApplyFn>(
&'a self,
stream: impl Into<Stream>,
apply: ApplyFn,
) -> SupportsColorsDisplay<'a, Self, Out, ApplyFn>where
ApplyFn: Fn(&'a Self) -> Out,
Apply a given transformation function to all formatters if the given stream supports at least basic ANSI colors, allowing you to conditionally apply given styles/colors.
Requires the supports-colors feature.
use owo_colors::{Stream, OwoColorize};
println!(
"{}",
"woah! error! if this terminal supports colors, it's blue"
.if_supports_color(Stream::Stdout, |text| text.bright_blue())
);This function also accepts supports_color version 2’s Stream, and also the deprecated
supports_color version 1’s Stream.
use owo_colors::OwoColorize;
#[cfg(feature = "supports-colors")]
use supports_color::Stream;
println!(
"{}",
"woah! error! if this terminal supports colors, it's blue"
.if_supports_color(Stream::Stdout, |text| text.bright_blue())
);Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".